<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use App\Models\PersonalModel;
use App\Models\CargoModel;
use App\Models\EspecialidadModel;
use App\Models\DetallePermisosModel;
use App\Models\PermisosModel;

class Personal extends BaseController
{
    protected $personal, $session, $cargo, $reglas, $reglasCambia, $especialidad, $reglaslogin, $reglasCambiaClave, $permisos, $detalle_rol;

    public function __construct()
    {
        $this->personal = new PersonalModel();
        $this->cargo = new CargoModel();
        $this->especialidad = new EspecialidadModel();
        $this->detalle_rol = new DetallePermisosModel();
        $this->permisos = new PermisosModel();

        $this->session = session();

        helper(['form']);


        $this->reglas =
            [
                'ci' =>
                [
                    'rules' => 'required|is_unique[personal.ci]',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                        'is_unique' => 'El campo {field} debe ser unico.'
                    ]
                ],
                'nombre' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'id_especialidad' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],

                'telefono' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'email' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'usuario' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'clave' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ]
            ];

        $this->reglasCambia =
            [
                'nombre' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'ci' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'id_especialidad' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],

                'telefono' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ],
                'email' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ]
            ];

        $this->reglaslogin =
            [
                'usuario' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.'
                    ]
                ],
                'clave'  =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.'
                    ]
                ]
            ];
        $this->reglasCambiaClave =
            [

                'clave'  =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.'
                    ]
                ]
            ];
    }


    public function valida()
    {
        $recaptchaResponse = $this->request->getPost('g-recaptcha-response');

        $url = 'https://www.google.com/recaptcha/api/siteverify';
        $data = [
            'secret' => env('RECAPTCHA_SECRET_KEY'),
            'response' => $recaptchaResponse
        ];

        $options = [
            'http' => [
                'header' => "Content-type: application/x-www-form-urlencoded\r\n",
                'method' => 'POST',
                'content' => http_build_query($data)
            ]
        ];

        $context = stream_context_create($options);
        $result = file_get_contents($url, false, $context);
        $response = json_decode($result);

        if ($response->success) {
            // reCAPTCHA válido, procede a procesar el formulario
            if ($this->request->getMethod() == "post" && $this->validate($this->reglaslogin)) {
                $usuario = $this->request->getPost('usuario');
                $clave = $this->request->getPost('clave');
                $datosUsuario = $this->personal->datosSession($usuario);

                if ($datosUsuario != null) {
                    if (password_verify($clave, $datosUsuario['clave'])) {
                        $datosSesion = [
                            'id_personal' => $datosUsuario['id_personal'],
                            'nombre_personal' => $datosUsuario['nombre_personal'],
                            'cargo' => $datosUsuario['nombre_cargo'],
                            'id_cargo' => $datosUsuario['id_cargo'],
                        ];
                        $session = session();
                        $session->set($datosSesion);
                        return redirect()->to(base_url() . '/tablero');
                    } else {
                        $data['error'] = "Las contraseñas no coinciden";
                        echo view('login', $data);
                    }
                } else {
                    $data['error'] = "El usuario no existe";
                    echo view('login', $data);
                }
            } else {
                $data = ['validation' => $this->validator];
                echo view('login', $data);
            }
        } else {
            // reCAPTCHA inválido, manejar el error
            return redirect()->back()->with('error', 'reCAPTCHA verification failed');
        }
    }


    /* INICIO */
    public function index()
    {
        $personal = $this->personal->datos();
        $cargo = $this->cargo->where('estado_cargo', 1)->findAll();
        $especialidad = $this->especialidad->where('estado_especialidad', 1)->findAll();
        $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);


        $data = ['datos' => $personal, 'cargos' => $cargo, 'especialidades' => $especialidad, 'validacion_sw' => 0, 'permisos' => $permisos];
        $view =
            view('header', $data) .
            view('personal/personal', $data) .
            view('footer');
        return $view;
    }
    public function insertar()
    {
        if ($this->request->getMethod() == "post" && $this->validate($this->reglas)) {
            $hash = $this->request->getPost('clave');

            $this->personal->save([
                'nombre_personal' => strtoupper($this->request->getPost('nombre')),
                'ci' => $this->request->getPost('ci'),
                'extension' => $this->request->getPost('extencion'),
                'id_especialidad' => $this->request->getPost('id_especialidad'),
                'telefono' => $this->request->getPost('telefono'),
                'email' => $this->request->getPost('email'),
                'id_cargo' => $this->request->getPost('id_cargo'),
                'usuario' =>  $this->request->getPost('usuario'),
                'clave' => password_hash("$hash", PASSWORD_DEFAULT),
                'estado_personal' => 1
            ]);

            return redirect()->to(base_url() . 'personal');
        } else {
            $personal = $this->personal->datos();
            $cargo = $this->cargo->where('estado_cargo', 1)->findAll();
            $especialidad = $this->especialidad->where('estado_especialidad', 1)->findAll();
            $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

            $data = ['datos' => $personal, 'validation' => $this->validator, 'cargos' => $cargo, 'validacion_sw' => 0, 'especialidades' => $especialidad, 'permisos' => $permisos];
            $view =
                view('header', $data) .
                view('personal/personal', $data) .
                view('footer');
            return $view;
        }
    }

    public function editar($id, $valid = null)
    {
        $personal = $this->personal->where('id_personal', $id)->first();
        $cargo = $this->cargo->where('estado_cargo', 1)->findAll();
        $especialidad = $this->especialidad->where('estado_especialidad', 1)->findAll();
        $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

        if ($valid != null) {
            $data = ['datos' => $personal, 'validation' => $valid, 'cargos' => $cargo, 'especialidades' => $especialidad, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('personal/editar', $data);
            echo view('footer');
        } else {
            $data = ['datos' => $personal, 'cargos' => $cargo, 'especialidades' => $especialidad, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('personal/editar', $data);
            echo view('footer');
        }
    }

    public function actualizar()
    {
        $id = $this->request->getPost('id_personal');
        $ci = $this->request->getPost('ci');
        $datos = $this->personal->where('id_personal !=', $id)->where('ci', $ci)->first();
        if (!$datos) {

            if ($this->request->getMethod() == "post" && $this->validate($this->reglasCambia)) {

                $this->personal->update($this->request->getPost('id_personal'), [
                    'nombre_personal' => strtoupper($this->request->getPost('nombre')),
                    'id_especialidad' => strtoupper($this->request->getPost('id_especialidad')),
                    'telefono' => $this->request->getPost('telefono'),
                    'ci' => $this->request->getPost('ci'),
                    'extension' => $this->request->getPost('extencion'),
                    'email' => $this->request->getPost('email'),
                    'id_cargo' => $this->request->getPost('id_cargo'),
                    'estado_personal' => $this->request->getPost('estado_personal'),
                ]);

                return redirect()->to(base_url() . 'personal');
            } else {

                return $this->editar($this->request->getPost('id_personal'), $this->validator);
            }
        } else {
            $personal = $this->personal->datos();
           // $personal = $this->personal->findAll();
            $cargo = $this->cargo->where('estado_cargo', 1)->findAll();
            $especialidad = $this->especialidad->where('estado_especialidad', 1)->findAll();
            $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);


            $data = ['datos' => $personal, 'validacion_sw' => 1, 'cargos' => $cargo, 'especialidades' => $especialidad, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('personal/personal', $data);
            echo view('footer');
        }
    }

    public function login()
    {
        echo view('login');
    }

    public function logout()
    {
        $session = session();
        $session->destroy();
        return redirect()->to(base_url());
    }

    public function editar_clave($id, $valid = null)
    {
        $cargo = $this->cargo->findAll();
        $personal = $this->personal->where('id_personal', $id)->first();
        $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

        if ($valid != null) {
            $data = ['datos' => $personal, 'validation' => $valid, 'cargo' => $cargo, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('personal/editar_clave', $data);
            echo view('footer');
        } else {
            $data = ['datos' => $personal, 'cargo' => $cargo, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('personal/editar_clave', $data);
            echo view('footer');
        }
    }


    public function actualizar_clave()
    {
        if ($this->request->getMethod() == "post" && $this->validate($this->reglasCambiaClave)) {
            $session = session();
            $idUsuario =  $session->id_personal;
            $hash = $this->request->getPost('clave');

            $this->personal->update($this->request->getPost('id_personal'), [
                'usuario' => $this->request->getPost('usuario'),
                'clave' => password_hash("$hash", PASSWORD_DEFAULT),
            ]);

            return redirect()->to(base_url() . 'personal');
        } else {
            return $this->editar_clave($this->request->getPost('id_personal'), $this->validator);
        }
    }
}
