<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use App\Models\ServicioModel;
use App\Models\DetallePermisosModel;
use App\Models\PermisosModel;

class Servicio extends BaseController
{
    protected $servicio, $session, $roles, $reglas, $reglasCambia, $permisos, $detalle_rol;

    public function __construct()
    {
        $this->servicio = new ServicioModel();
        $this->detalle_rol = new DetallePermisosModel();
        $this->permisos = new PermisosModel();

        $this->session = session();

        helper(['form']);


        $this->reglas =
            [
                'nombre_servicio' =>
                [
                    'rules' => 'required|is_unique[servicios.nombre_servicio]',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                        'is_unique' => 'El campo {field} debe ser unico.'
                    ]
                ]
            ];

        $this->reglasCambia =
            [
                'nombre_servicio' =>
                [
                    'rules' => 'required',
                    'errors' => [
                        'required' => 'El campo {field} es obligatorio.',
                    ]
                ]  
                
            ];
    }

    /* INICIO */
    public function index()
    {
        $servicio = $this->servicio->findAll();
        $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

        $data = ['datos' => $servicio, 'validacion_sw' => 0, 'permisos' => $permisos];
        $view =
            view('header', $data) .
            view('servicio/servicio', $data) .
            view('footer');
        return $view;
    }
    public function insertar()
    {
        if ($this->request->getMethod() == "post" && $this->validate($this->reglas)) {

            $this->servicio->save([
                'nombre_servicio' => strtoupper($this->request->getPost('nombre_servicio')),
                'estado_servicio' => 1,
           
            ]);

            return redirect()->to(base_url() . 'servicio');
        } else {
            $servicio = $this->servicio->findAll();
            $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

            $data = ['datos' => $servicio, 'validation' => $this->validator, 'validacion_sw' => 0, 'permisos' => $permisos];
            $view =
                view('header', $data) .
                view('servicio/servicio', $data) .
                view('footer');
            return $view;
        }
    }

    public function editar($id, $valid = null)
    {
        $servicio = $this->servicio->where('id_servicio', $id)->first();
        $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

        if ($valid != null) {
            $data = ['datos' => $servicio, 'validation' => $valid, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('servicio/editar', $data);
            echo view('footer');
        } else {
            $data = ['datos' => $servicio, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('servicio/editar', $data);
            echo view('footer');
        }
    }

    public function actualizar()
    {
        $id = $this->request->getPost('id_servicio');
        $nombre_servicio = $this->request->getPost('nombre_servicio');
        $datos = $this->servicio->where('id_servicio !=', $id)->where('nombre_servicio', $nombre_servicio)->first();
        if (!$datos) {

            if ($this->request->getMethod() == "post" && $this->validate($this->reglasCambia)) {

                $this->servicio->update($this->request->getPost('id_servicio'), [
                    'nombre_servicio' => strtoupper($this->request->getPost('nombre_servicio')),
                    'estado_servicio' => $this->request->getPost('estado_servicio'),
                ]);
                return redirect()->to(base_url() . 'servicio');
            } else {
                return $this->editar($this->request->getPost('id_servicio'), $this->validator);
            }
        } else {

            $servicio = $this->servicio->findAll();
            $permisos = $this->permisos->nombre_permisos($this->session->id_cargo);

            $data = ['datos' => $servicio, 'validacion_sw' => 1, 'permisos' => $permisos];
            echo view('header', $data);
            echo view('servicio/servicio', $data);
            echo view('footer');
        }
    }
}
